_me = obj_loader.prototype;
function obj_loader(){};

/**
 * @brief:
 * @date : 4.1.2007 12:21:09
 **/
_me._value = function(s){
	if (typeof s === 'undefined') {
		return this._getAnchor('content').innerHTML;
	}
	this._getAnchor('content').innerHTML = s;
	return this;
};